document.addEventListener('DOMContentLoaded', () => {
  const analyzeBtn = document.getElementById('analyzeBtn');
  const usernameInput = document.getElementById('username');
  const resultsSection = document.querySelector('.results-section');
  const metricValues = document.querySelectorAll('.metric .value');
  const recommendationList = document.querySelector('.recommendation-list');

  analyzeBtn.addEventListener('click', async () => {
    const username = usernameInput.value.trim();
    
    if (!username) {
      alert('Please enter a Twitter username');
      return;
    }

    // Show loading state
    metricValues.forEach(value => {
      value.textContent = 'Analyzing...';
    });
    recommendationList.innerHTML = '';

    try {
      // Simulate API call with mock data
      const analysis = await simulateAnalysis(username);

      // Update UI with analysis results
      metricValues[0].textContent = `${analysis.engagementRate}%`;
      metricValues[1].textContent = analysis.topContentType;
      metricValues[2].textContent = analysis.growthPotential;

      // Add recommendations
      analysis.recommendations.forEach(rec => {
        const li = document.createElement('li');
        li.textContent = rec;
        recommendationList.appendChild(li);
      });

      // Show results section
      resultsSection.classList.remove('hidden');
      setTimeout(() => resultsSection.classList.add('visible'), 10);
    } catch (error) {
      alert('Error analyzing profile. Please try again.');
      console.error(error);
    }
  });

  async function simulateAnalysis(username) {
    // Simulate API delay
    await new Promise(resolve => setTimeout(resolve, 1000));

    // Return mock data
    return {
      engagementRate: Math.floor(Math.random() * (30 - 10 + 1)) + 10,
      topContentType: ['Tweets', 'Threads', 'Media'][Math.floor(Math.random() * 3)],
      growthPotential: ['High', 'Medium', 'Low'][Math.floor(Math.random() * 3)],
      recommendations: [
        'Post more video content',
        'Engage with your audience daily',
        'Use relevant hashtags',
        'Collaborate with other creators',
        'Analyze your best-performing tweets'
      ]
    };
  }
});